==> jc-1.4.0.tar.gz: soot/jimple/toolkits/invoke/StaticInliner.h <==
// public class soot.jimple.toolkits.invoke.StaticInliner

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class fc89a3bf4eb2a468 soot_jimple_toolkits_invoke_StaticInliner

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_invoke_StaticInliner_H_
#define _JC_soot_jimple_toolkits_invoke_StaticInliner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_refs	_jc_soot_jimple_toolkits_invoke_StaticInliner$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_StaticInliner$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$refs	_jc_soot_jimple_toolkits_invoke_StaticInliner$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$nonrefs	_jc_soot_jimple_toolkits_invoke_StaticInliner$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object	_jc_soot_jimple_toolkits_invoke_StaticInliner$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vmethods	_jc_soot_jimple_toolkits_invoke_StaticInliner$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vtable	_jc_soot_jimple_toolkits_invoke_StaticInliner$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vtype	_jc_soot_jimple_toolkits_invoke_StaticInliner$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_StaticInliner$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_invoke_StaticInliner$method$computeAverageMethodSizeAndSaveOriginalSizes$69630d309e17aa94(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *);
extern void _jc_soot_jimple_toolkits_invoke_StaticInliner$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_invoke_StaticInliner$method_info$computeAverageMethodSizeAndSaveOriginalSizes$69630d309e17aa94;
extern _jc_method _jc_soot_jimple_toolkits_invoke_StaticInliner$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *_jc_soot_jimple_toolkits_invoke_StaticInliner$method$v$f3df50afa85a2397(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vmethods {
	void	(*computeAverageMethodSizeAndSaveOriginalSizes$69630d309e17aa94)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *);
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_invoke_StaticInliner$vmethods	soot_jimple_toolkits_invoke_StaticInliner;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_StaticInliner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_refs {
	struct _jc_java_util_HashMap$object	*methodToOriginalSize;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$refs {
    _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_refs	soot_jimple_toolkits_invoke_StaticInliner;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_nonrefs {
	jint	avgSize;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_nonrefs	soot_jimple_toolkits_invoke_StaticInliner;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object {
	_jc_soot_jimple_toolkits_invoke_StaticInliner$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_StaticInliner$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_StaticInliner$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_StaticInliner$vtype _jc_soot_jimple_toolkits_invoke_StaticInliner$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_StaticInliner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_StaticInliner$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_StaticInliner_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/invoke/StaticInliner.h <==
// public class soot.jimple.toolkits.invoke.StaticInliner

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class fc89a3bf4eb2a468 soot_jimple_toolkits_invoke_StaticInliner

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_invoke_StaticInliner_H_
#define _JC_soot_jimple_toolkits_invoke_StaticInliner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_refs	_jc_soot_jimple_toolkits_invoke_StaticInliner$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_StaticInliner$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$refs	_jc_soot_jimple_toolkits_invoke_StaticInliner$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$nonrefs	_jc_soot_jimple_toolkits_invoke_StaticInliner$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object	_jc_soot_jimple_toolkits_invoke_StaticInliner$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vmethods	_jc_soot_jimple_toolkits_invoke_StaticInliner$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vtable	_jc_soot_jimple_toolkits_invoke_StaticInliner$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vtype	_jc_soot_jimple_toolkits_invoke_StaticInliner$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_StaticInliner$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_invoke_StaticInliner$method$computeAverageMethodSizeAndSaveOriginalSizes$69630d309e17aa94(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_invoke_StaticInliner$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_invoke_StaticInliner$method_info$computeAverageMethodSizeAndSaveOriginalSizes$69630d309e17aa94;
extern _jc_method _jc_soot_jimple_toolkits_invoke_StaticInliner$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *_jc_soot_jimple_toolkits_invoke_StaticInliner$method$v$f3df50afa85a2397(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vmethods {
	void	(*computeAverageMethodSizeAndSaveOriginalSizes$69630d309e17aa94)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_invoke_StaticInliner$vmethods	soot_jimple_toolkits_invoke_StaticInliner;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_StaticInliner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_refs {
	struct _jc_java_util_HashMap$object	*methodToOriginalSize;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$refs {
    _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_refs	soot_jimple_toolkits_invoke_StaticInliner;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_nonrefs {
	jint	avgSize;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_invoke_StaticInliner$sub_nonrefs	soot_jimple_toolkits_invoke_StaticInliner;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_StaticInliner$object {
	_jc_soot_jimple_toolkits_invoke_StaticInliner$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_StaticInliner$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_StaticInliner$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_StaticInliner$vtype _jc_soot_jimple_toolkits_invoke_StaticInliner$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_StaticInliner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_StaticInliner$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_StaticInliner_H_ */
